@@ -1,5 +1,4 @@
 import os
-from pathlib import Path
 
 # Configuration file specifying the default covfee behavior
 # Can be overwritten via project config
@@ -18,10 +17,13 @@ COVFEE_SECRET_KEY = 'CHANGE_ME'
 SQLALCHEMY_ENGINE_OPTIONS = {'isolation_level': "READ UNCOMMITTED"}
 SQLALCHEMY_TRACK_MODIFICATIONS = False
 
+COVFEE_BASE_PATH = os.path.join(os.path.dirname(os.path.realpath(__file__)), '..')
+COVFEE_CLI_PATH = os.path.join(COVFEE_BASE_PATH, 'cli')
+COVFEE_CLIENT_PATH = os.path.join(COVFEE_BASE_PATH, 'client')
+SHARED_PATH = os.path.join(COVFEE_BASE_PATH, 'shared')
 # for storing the json schemata for validation
-SHARED_PATH = os.path.join(os.path.dirname(os.path.realpath(__file__)), '..', '..', 'shared')
-DOCS_SCHEMATA_PATH = os.path.join(os.path.dirname(os.path.realpath(__file__)), '..', '..', 'docs', 'schemata.json')
-FILTER_SCHEMATA_PATH = os.path.join(os.path.dirname(os.path.realpath(__file__)), '..', 'cli', 'schemata.json')
+DOCS_SCHEMATA_PATH = os.path.join(COVFEE_BASE_PATH, '..', 'docs', 'schemata.json')
+FILTER_SCHEMATA_PATH = os.path.join(COVFEE_BASE_PATH, 'cli', 'schemata.json')
 
 # Configure application to store JWTs in cookies. Whenever you make
 # a request to a protected endpoint, you will need to send in the
@@ -32,14 +34,14 @@ JWT_COOKIE_CSRF_PROTECT = False
 # PROJECT FOLDER PATHS
 
 # database
-DATABASE_RELPATH = os.path.join('.covfee', 'database.covfee.db')
+DATABASE_RELPATH = os.path.join(os.getcwd(), '.covfee', 'database.covfee.db')
 DATABASE_PATH = os.path.join(os.getcwd(), DATABASE_RELPATH)
 
 # project www and bundle location
 PROJECT_WWW_PATH = os.path.join(os.getcwd(), 'www')
 PROJECT_WWW_URL = os.path.join(BASE_URL, 'www')
 BUNDLE_URL = PROJECT_WWW_URL
-MASTER_BUNDLE_PATH = os.path.join(os.path.dirname(os.path.realpath(__file__)), '..', '..', 'client', 'bundles')
+MASTER_BUNDLE_PATH = os.path.join(COVFEE_BASE_PATH, 'client', 'bundles')
 
 # for project media
 MEDIA_PATH = os.path.join(os.getcwd(), 'www')
@@ -50,4 +52,4 @@ MEDIA_SERVER = True
 TMP_PATH = os.path.join(os.getcwd(), 'tmp')
 
 # DEV MODE SETTINGS
-DEV_BUNDLE_URL = 'http://localhost:8085/main.js'
\ No newline at end of file
+DEV_BUNDLE_URL = 'http://localhost:8085/main.js'
