@@ -1,11 +1,14 @@
+import os
 import json
 import datetime
 
-from .orm import db, app
+from flask import current_app as app
+
+from .db import db
 from .. import tasks
-import os
 pytype = type
 
+
 class Task(db.Model):
     """ Represents a single task, like eg. annotating one video """
     __tablename__ = 'tasks'
