@@ -14,7 +14,10 @@ export interface BasicVideo {
 }
 
 export interface MultiviewVideo {
-    type: 'video'
+    /**
+     * @default "video-multiview"
+     */
+    type: 'video-multiview'
     /**
      * URL to video files
      */
